@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 """
-    Simple script for quicly making an h5 file from a .fil.
+    Simple script for making an h5 file from a .fil.
 
     ..author: Emilio Enriquez (jeenriquez@gmail.com)
 
@@ -11,6 +11,7 @@ import sys
 import os
 import time
 from argparse import ArgumentParser
+from .utils import change_the_ext
 
 # Logging set up
 import logging
@@ -44,11 +45,9 @@ def make_h5_file(filename, out_dir='./', new_filename=None, t_start=None, t_stop
     """
 
     wf = Waterfall(filename, load_data=False, t_start=t_start, t_stop=t_stop)
-    if not new_filename:
-        new_filename = out_dir+filename.replace('.fil', '.h5').split('/')[-1]
 
-    if '.h5' not in new_filename:
-        new_filename = new_filename+'.h5'
+    if not new_filename:
+        new_filename = out_dir + change_the_ext(filename, 'fil', 'h5').split('/')[-1]
 
     t0 = time.time()
     write_to_h5(wf, new_filename)
